@@ -22,6 +22,7 @@
 #include "autotype/AutoType.h"
 #include "core/Config.h"
 #include "core/Global.h"
+#include "core/Resources.h"
 #include "gui/MainWindow.h"
 #include "gui/osutils/OSUtils.h"
 #include "gui/styles/dark/DarkStyle.h"
@@ -131,6 +132,12 @@ Application::Application(int& argc, char** argv)
         qWarning()
             << QObject::tr("The lock file could not be created. Single-instance mode disabled.").toUtf8().constData();
     }
+
+    connect(osUtils, &OSUtilsBase::interfaceThemeChanged, this, [this]() {
+        if (config()->get(Config::GUI_ApplicationTheme).toString() != "classic") {
+            applyTheme();
+        }
+    });
 }
 
 Application::~Application()
@@ -153,15 +160,15 @@ void Application::applyTheme()
         }
 #endif
     }
-
+    QPixmapCache::clear();
     if (appTheme == "light") {
-        setStyle(new LightStyle);
-        // Workaround Qt 5.15+ bug
-        setPalette(style()->standardPalette());
+        auto* s = new LightStyle;
+        setPalette(s->standardPalette());
+        setStyle(s);
     } else if (appTheme == "dark") {
-        setStyle(new DarkStyle);
-        // Workaround Qt 5.15+ bug
-        setPalette(style()->standardPalette());
+        auto* s = new DarkStyle;
+        setPalette(s->standardPalette());
+        setStyle(s);
         m_darkTheme = true;
     } else {
         // Classic mode, don't check for dark theme on Windows
@@ -279,13 +286,26 @@ void Application::socketReadyRead()
     }
 
     QStringList fileNames;
-    in >> fileNames;
-    for (const QString& fileName : asConst(fileNames)) {
-        const QFileInfo fInfo(fileName);
-        if (fInfo.isFile() && fInfo.suffix().toLower() == "kdbx") {
-            emit openFile(fileName);
+    quint32 id;
+    in >> id;
+
+    // TODO: move constants to enum
+    switch (id) {
+    case 1:
+        in >> fileNames;
+        for (const QString& fileName : asConst(fileNames)) {
+            const QFileInfo fInfo(fileName);
+            if (fInfo.isFile() && fInfo.suffix().toLower() == "kdbx") {
+                emit openFile(fileName);
+            }
         }
+
+        break;
+    case 2:
+        getMainWindow()->lockAllDatabases();
+        break;
     }
+
     socket->deleteLater();
 }
 
@@ -298,6 +318,12 @@ bool Application::isAlreadyRunning() const
     return config()->get(Config::SingleInstance).toBool() && m_alreadyRunning;
 }
 
+/**
+ * Send to-open file names to the running UI instance
+ *
+ * @param fileNames - list of file names to open
+ * @return true if all operations succeeded (connection made, data sent, connection closed)
+ */
 bool Application::sendFileNamesToRunningInstance(const QStringList& fileNames)
 {
     QLocalSocket client;
@@ -310,13 +336,48 @@ bool Application::sendFileNamesToRunningInstance(const QStringList& fileNames)
     QByteArray data;
     QDataStream out(&data, QIODevice::WriteOnly);
     out.setVersion(QDataStream::Qt_5_0);
-    out << quint32(0) << fileNames;
+    out << quint32(0); // reserve space for block size
+    out << quint32(1); // ID for file name send. TODO: move to enum
+    out << fileNames; // send file names to be opened
     out.device()->seek(0);
-    out << quint32(data.size() - sizeof(quint32));
+    out << quint32(data.size() - sizeof(quint32)); // replace the previous constant 0 with block size
 
     const bool writeOk = client.write(data) != -1 && client.waitForBytesWritten(WaitTimeoutMSec);
     client.disconnectFromServer();
-    const bool disconnected = client.waitForDisconnected(WaitTimeoutMSec);
+    const bool disconnected =
+        client.state() == QLocalSocket::UnconnectedState || client.waitForDisconnected(WaitTimeoutMSec);
+    return writeOk && disconnected;
+}
+
+/**
+ * Locks all open databases in the running instance
+ *
+ * @return true if the "please lock" signal was sent successfully
+ */
+bool Application::sendLockToInstance()
+{
+    // Make a connection to avoid SIGSEGV
+    QLocalSocket client;
+    client.connectToServer(m_socketName);
+    const bool connected = client.waitForConnected(WaitTimeoutMSec);
+    if (!connected) {
+        return false;
+    }
+
+    // Send lock signal
+    QByteArray data;
+    QDataStream out(&data, QIODevice::WriteOnly);
+    out.setVersion(QDataStream::Qt_5_0);
+    out << quint32(0); // reserve space for block size
+    out << quint32(2); // ID for database lock. TODO: move to enum
+    out.device()->seek(0);
+    out << quint32(data.size() - sizeof(quint32)); // replace the previous constant 0 with block size
+
+    // Finish gracefully
+    const bool writeOk = client.write(data) != -1 && client.waitForBytesWritten(WaitTimeoutMSec);
+    client.disconnectFromServer();
+    const bool disconnected =
+        client.state() == QLocalSocket::UnconnectedState || client.waitForConnected(WaitTimeoutMSec);
     return writeOk && disconnected;
 }
 
